@@ -1,30 +1,24 @@
 #!/usr/bin/python2
 import json
-
-try:
-    from urllib.parse import quote
-except:
-    from urllib import quote
-
-
+from urllib import quote
 class relaxx:
-    r = None  # the request session
-    def __init__(self, relaxxurl="http://lounge.mpd.shack/",timeout=1):
-        self.baseurl = relaxxurl
-        self.timeout = timeout
-        import requests
-        self.r = requests.Session()
-        self.r.get(relaxxurl,timeout=self.timeout)  # grab cookie
-        self.r.headers.update({"Referer": relaxxurl})
 
+    def __init__(self,relaxxurl="http://lounge.mpd.shack/"):
+        self.baseurl=relaxxurl
+        import requests
+        ret = requests.get(relaxxurl) # grab cookie
+        try:
+            self.r = requests.session(cookies=ret.cookies,headers={"Referer":relaxxurl})
+        except:
+            print ("you are missing the `requests` dependency, please do a `pip install requests`")
     def _status(self,value=0,data="json=null"):
         """
         value is some weird current playlist value, 0 seems to work
         data is url encoded kv-store
         """
         # TODO get the current playlist value
-        url = self.baseurl+"include/controller-ping.php?value=%s" % value
-        return self.r.post(url,data="json=null",timeout=self.timeout).text
+        url=self.baseurl+"include/controller-ping.php?value=%s"%value
+        return self.r.post(url,data="json=null").text
 
     def _playlist(self,action,value="",json="null",method="get"):
         """
@@ -42,9 +36,9 @@ class relaxx:
         """
         url=self.baseurl+"include/controller-playlist.php?action=%s&value=%s&json=%s"%(action,value,json)
         if method== "get":
-            return self.r.get(url,timeout=self.timeout).text
+            return self.r.get(url).text
         elif method == "post":
-            return r.post(url,timeout=self.timeout).text
+            return r.post(url).text
         else:
             raise Exception("unknown method %s")
 
@@ -58,9 +52,9 @@ class relaxx:
         url=self.baseurl+"include/controller-playback.php?action=%s&value=%s&json=%s"%(action,value,json)
         # probably obsolete because everything is "get"
         if method== "get":
-            return self.r.get(url,timeout=self.timeout).text
+            return self.r.get(url).text
         elif method == "post":
-            return r.post(url,timeout=self.timeout).text
+            return r.post(url).text
         else:
             raise Exception("unknown method %s")
 
@@ -69,26 +63,23 @@ class relaxx:
         both, post and get the url seem to work here...
         """
         url=self.baseurl+"include/controller-netradio.php?playlist=%s"%quote(playlist)
-        return self.r.get(url,timeout=self.timeout).text
+        return self.r.get(url).text
 
     def add_radio(self,playlist=""):
-        print(playlist)
-        print(self._radio(playlist))
-        print(json.loads(self._radio(playlist))) #[1:-1])["url"]
+        print playlist
+        print self._radio(playlist)
+        print json.loads(self._radio(playlist)) #[1:-1])["url"]
         resolved_url= json.loads(self._radio(playlist)[1:-1])["url"]
         self.add_song(resolved_url)
 
     def add_song(self,path):
         return self._playlist("addSong",path)
-    def next_song(self):
-        return json.loads(self._playback("nextSong"))
-    def prev_song(self):
-        return json.loads(self._playback("prevSong"))
+
     def get_first(self):
-        return self.state()['playlist']['file'][0]
+        return json.loads(self._playlist("getPlaylistInfo","0",""))[0]
 
     def get_last(self):
-        return self.state()['playlist']['file'][-1]
+        return json.loads(self._playlist("getPlaylistInfo","0",""))[-1]
 
     def clear(self):
         return self._playlist("clear")
@@ -126,30 +117,22 @@ class relaxx:
     def is_running(self):
         return self.state()["status"]["state"] == "play"
 
-    def get_current(self):
+    def playing(self):
         """ returns "" if not running
         """
         state = self.state()
         if state["status"]["state"] == "play" :
             ident = state["status"]["song"]
-            return state["playlist"]["file"][int(ident)]
-
-        else:
-            return {}
-    def playing(self):
-        current = self.get_current()
-        if current:
+            current = state["playlist"]["file"][int(ident)]
             return current.get("Name",current.get("Artist","unkown artist")) + " - " + current.get("Title","unknown title")
         else:
             return ""
 
-
 if __name__ == "__main__":
-    print("Called as Main")
     r = relaxx()
-    print(r.state())
-    print(r.playing())
-    #print(r.add_radio("http://deluxetelevision.com/livestreams/radio/DELUXE_RADIO.pls"))
+    print r.state()
+    print r.playing()
+    print r.add_radio("http://deluxetelevision.com/livestreams/radio/DELUXE_RADIO.pls")
     #print r.clear()
     #print r.add_radio("http://somafm.com/lush.pls")
     #print r.get_first()["Id"]
